==> esp8266-0.3.0.crate: esp8266-0.3.0/src/rtc.rs <==
#[doc = r"Register block"]
#[repr(C)]
pub struct RegisterBlock {
    _reserved0: [u8; 20usize],
    #[doc = "0x14 - RTC_STATE1"]
    pub rtc_state1: crate::Reg<rtc_state1::RTC_STATE1_SPEC>,
    _reserved1: [u8; 24usize],
    #[doc = "0x30 - RTC_STORE0"]
    pub rtc_store0: crate::Reg<rtc_store0::RTC_STORE0_SPEC>,
    _reserved2: [u8; 52usize],
    #[doc = "0x68 - RTC_GPIO_OUT"]
    pub rtc_gpio_out: crate::Reg<rtc_gpio_out::RTC_GPIO_OUT_SPEC>,
    _reserved3: [u8; 8usize],
    #[doc = "0x74 - RTC_GPIO_ENABLE"]
    pub rtc_gpio_enable: crate::Reg<rtc_gpio_enable::RTC_GPIO_ENABLE_SPEC>,
    _reserved4: [u8; 20usize],
    #[doc = "0x8c - RTC_GPIO_IN_DATA"]
    pub rtc_gpio_in_data: crate::Reg<rtc_gpio_in_data::RTC_GPIO_IN_DATA_SPEC>,
    #[doc = "0x90 - RTC_GPIO_CONF"]
    pub rtc_gpio_conf: crate::Reg<rtc_gpio_conf::RTC_GPIO_CONF_SPEC>,
    _reserved6: [u8; 12usize],
    #[doc = "0xa0 - PAD_XPD_DCDC_CONF"]
    pub pad_xpd_dcdc_conf: crate::Reg<pad_xpd_dcdc_conf::PAD_XPD_DCDC_CONF_SPEC>,
}
#[doc = "RTC_STORE0 register accessor: an alias for `Reg<RTC_STORE0_SPEC>`"]
pub type RTC_STORE0 = crate::Reg<rtc_store0::RTC_STORE0_SPEC>;
#[doc = "RTC_STORE0"]
pub mod rtc_store0;
#[doc = "RTC_STATE1 register accessor: an alias for `Reg<RTC_STATE1_SPEC>`"]
pub type RTC_STATE1 = crate::Reg<rtc_state1::RTC_STATE1_SPEC>;
#[doc = "RTC_STATE1"]
pub mod rtc_state1;
#[doc = "PAD_XPD_DCDC_CONF register accessor: an alias for `Reg<PAD_XPD_DCDC_CONF_SPEC>`"]
pub type PAD_XPD_DCDC_CONF = crate::Reg<pad_xpd_dcdc_conf::PAD_XPD_DCDC_CONF_SPEC>;
#[doc = "PAD_XPD_DCDC_CONF"]
pub mod pad_xpd_dcdc_conf;
#[doc = "RTC_GPIO_CONF register accessor: an alias for `Reg<RTC_GPIO_CONF_SPEC>`"]
pub type RTC_GPIO_CONF = crate::Reg<rtc_gpio_conf::RTC_GPIO_CONF_SPEC>;
#[doc = "RTC_GPIO_CONF"]
pub mod rtc_gpio_conf;
#[doc = "RTC_GPIO_ENABLE register accessor: an alias for `Reg<RTC_GPIO_ENABLE_SPEC>`"]
pub type RTC_GPIO_ENABLE = crate::Reg<rtc_gpio_enable::RTC_GPIO_ENABLE_SPEC>;
#[doc = "RTC_GPIO_ENABLE"]
pub mod rtc_gpio_enable;
#[doc = "RTC_GPIO_IN_DATA register accessor: an alias for `Reg<RTC_GPIO_IN_DATA_SPEC>`"]
pub type RTC_GPIO_IN_DATA = crate::Reg<rtc_gpio_in_data::RTC_GPIO_IN_DATA_SPEC>;
#[doc = "RTC_GPIO_IN_DATA"]
pub mod rtc_gpio_in_data;
#[doc = "RTC_GPIO_OUT register accessor: an alias for `Reg<RTC_GPIO_OUT_SPEC>`"]
pub type RTC_GPIO_OUT = crate::Reg<rtc_gpio_out::RTC_GPIO_OUT_SPEC>;
#[doc = "RTC_GPIO_OUT"]
pub mod rtc_gpio_out;

==> esp8266-0.6.0.crate: esp8266-0.6.0/src/rtc.rs <==
#[doc = r"Register block"]
#[repr(C)]
pub struct RegisterBlock {
    _reserved0: [u8; 0x14],
    #[doc = "0x14 - RTC_STATE1"]
    pub rtc_state1: crate::Reg<rtc_state1::RTC_STATE1_SPEC>,
    _reserved1: [u8; 0x18],
    #[doc = "0x30 - RTC_STORE0"]
    pub rtc_store0: crate::Reg<rtc_store0::RTC_STORE0_SPEC>,
    _reserved2: [u8; 0x34],
    #[doc = "0x68 - RTC_GPIO_OUT"]
    pub rtc_gpio_out: crate::Reg<rtc_gpio_out::RTC_GPIO_OUT_SPEC>,
    _reserved3: [u8; 0x08],
    #[doc = "0x74 - RTC_GPIO_ENABLE"]
    pub rtc_gpio_enable: crate::Reg<rtc_gpio_enable::RTC_GPIO_ENABLE_SPEC>,
    _reserved4: [u8; 0x14],
    #[doc = "0x8c - RTC_GPIO_IN_DATA"]
    pub rtc_gpio_in_data: crate::Reg<rtc_gpio_in_data::RTC_GPIO_IN_DATA_SPEC>,
    #[doc = "0x90 - RTC_GPIO_CONF"]
    pub rtc_gpio_conf: crate::Reg<rtc_gpio_conf::RTC_GPIO_CONF_SPEC>,
    _reserved6: [u8; 0x0c],
    #[doc = "0xa0 - PAD_XPD_DCDC_CONF"]
    pub pad_xpd_dcdc_conf: crate::Reg<pad_xpd_dcdc_conf::PAD_XPD_DCDC_CONF_SPEC>,
}
#[doc = "RTC_STORE0 register accessor: an alias for `Reg<RTC_STORE0_SPEC>`"]
pub type RTC_STORE0 = crate::Reg<rtc_store0::RTC_STORE0_SPEC>;
#[doc = "RTC_STORE0"]
pub mod rtc_store0;
#[doc = "RTC_STATE1 register accessor: an alias for `Reg<RTC_STATE1_SPEC>`"]
pub type RTC_STATE1 = crate::Reg<rtc_state1::RTC_STATE1_SPEC>;
#[doc = "RTC_STATE1"]
pub mod rtc_state1;
#[doc = "PAD_XPD_DCDC_CONF register accessor: an alias for `Reg<PAD_XPD_DCDC_CONF_SPEC>`"]
pub type PAD_XPD_DCDC_CONF = crate::Reg<pad_xpd_dcdc_conf::PAD_XPD_DCDC_CONF_SPEC>;
#[doc = "PAD_XPD_DCDC_CONF"]
pub mod pad_xpd_dcdc_conf;
#[doc = "RTC_GPIO_CONF register accessor: an alias for `Reg<RTC_GPIO_CONF_SPEC>`"]
pub type RTC_GPIO_CONF = crate::Reg<rtc_gpio_conf::RTC_GPIO_CONF_SPEC>;
#[doc = "RTC_GPIO_CONF"]
pub mod rtc_gpio_conf;
#[doc = "RTC_GPIO_ENABLE register accessor: an alias for `Reg<RTC_GPIO_ENABLE_SPEC>`"]
pub type RTC_GPIO_ENABLE = crate::Reg<rtc_gpio_enable::RTC_GPIO_ENABLE_SPEC>;
#[doc = "RTC_GPIO_ENABLE"]
pub mod rtc_gpio_enable;
#[doc = "RTC_GPIO_IN_DATA register accessor: an alias for `Reg<RTC_GPIO_IN_DATA_SPEC>`"]
pub type RTC_GPIO_IN_DATA = crate::Reg<rtc_gpio_in_data::RTC_GPIO_IN_DATA_SPEC>;
#[doc = "RTC_GPIO_IN_DATA"]
pub mod rtc_gpio_in_data;
#[doc = "RTC_GPIO_OUT register accessor: an alias for `Reg<RTC_GPIO_OUT_SPEC>`"]
pub type RTC_GPIO_OUT = crate::Reg<rtc_gpio_out::RTC_GPIO_OUT_SPEC>;
#[doc = "RTC_GPIO_OUT"]
pub mod rtc_gpio_out;
